.. exojax documentation master file, created by
   sphinx-quickstart on Mon Jan 11 14:38:51 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.
   
ExoGibbs
==================================

Version 0.2

|:frog:| `DeepWiki for ExoGibbs <https://deepwiki.com/HajimeKawahara/exogibbs>`_


`ExoGibbs <https://github.com/HajimeKawahara/exogibbs>`_ provides an auto-differentiable thermalchemical equilibrium solver
based on the Gibbs free energy minimization method, powered by `JAX <https://github.com/google/jax>`_. 


Contents
==================================

.. toctree::
   :maxdepth: 2
   :caption: PRESETS:

   presets/ykb4.rst
   
   
.. toctree::
   :maxdepth: 1
   :caption: API:

   exogibbs/exogibbs.rst




License & Attribution
---------------------

Copyright 2025-, Contributors

- `Hajime Kawahara <http://secondearths.sakura.ne.jp/en/index.html>`_ (@HajimeKawahara, maintainer)
- `Yui Kawashima <https://sites.google.com/view/yuikawashima/home>`_ (@ykawashima, the reference code author we inherit, the presets ykb4 originally comes from this code.)
-

ExoGibbs is free software made available under the MIT License.
   
